==> qt-creator-1.3.1-src.zip: qt-creator-1.3.1-src/src/libs/cplusplus/GenTemplateInstance.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef GENTEMPLATEINSTANCE_H
#define GENTEMPLATEINSTANCE_H

#include <TypeVisitor.h>
#include <NameVisitor.h>
#include <FullySpecifiedType.h>

#include "LookupContext.h"

#include <QtCore/QList>
#include <QtCore/QPair>

namespace CPlusPlus {

class CPLUSPLUS_EXPORT GenTemplateInstance
{
public:
    typedef QList< QPair<Identifier *, FullySpecifiedType> > Substitution;

public:
    GenTemplateInstance(const LookupContext &context, const Substitution &substitution);

    FullySpecifiedType operator()(Symbol *symbol);

    Control *control() const;

private:
    Symbol *_symbol;
    LookupContext _context;
    const Substitution _substitution;
};

} // end of namespace CPlusPlus

#endif // GENTEMPLATEINSTANCE_H

==> qt-creator-2.0.0-rc1-src.zip: qt-creator-2.0.0-rc1-src/src/libs/cplusplus/GenTemplateInstance.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef GENTEMPLATEINSTANCE_H
#define GENTEMPLATEINSTANCE_H

#include <TypeVisitor.h>
#include <NameVisitor.h>
#include <FullySpecifiedType.h>

#include "LookupContext.h"

#include <QtCore/QList>
#include <QtCore/QPair>

namespace CPlusPlus {

class CPLUSPLUS_EXPORT GenTemplateInstance
{
public:
    typedef QList< QPair<const Identifier *, FullySpecifiedType> > Substitution;

public:
    GenTemplateInstance(const LookupContext &context, const Substitution &substitution);

    FullySpecifiedType operator()(Symbol *symbol);

    Control *control() const;

private:
    Symbol *_symbol;
    LookupContext _context;
    const Substitution _substitution;
};

} // end of namespace CPlusPlus

#endif // GENTEMPLATEINSTANCE_H
